@@ -114,7 +114,7 @@ public:
   bool m_relaxed_timestamp_checking;
 
 public:
-  generic_packetizer_c(generic_reader_c *reader, track_info_c &ti);
+  generic_packetizer_c(generic_reader_c *reader, track_info_c &ti, track_type type);
   virtual ~generic_packetizer_c();
 
   virtual bool contains_gap();
@@ -177,7 +177,8 @@ public:
   virtual uint64_t get_uid() const {
     return m_huid;
   }
-  virtual void set_track_type(int type, timestamp_factory_application_e tfa_mode = TFA_AUTOMATIC);
+  void set_track_type(track_type type);
+  void set_timestamp_factory_application_mode(timestamp_factory_application_e tfa_mode);
   virtual int get_track_type() const {
     return m_htrack_type;
   }
@@ -220,12 +221,7 @@ public:
   virtual void set_audio_emphasis_impl(libebml::EbmlMaster &audio, audio_emphasis_c::mode_e audio_emphasis);
 
   virtual void set_video_interlaced_flag(bool interlaced);
-  virtual void set_video_pixel_width(int width);
-  virtual void set_video_pixel_height(int height);
   virtual void set_video_pixel_dimensions(int width, int height);
-  virtual void set_video_display_width(int width);
-  virtual void set_video_display_height(int height);
-  virtual void set_video_display_unit(int unit);
   virtual void set_video_display_dimensions(int width, int height, int unit, option_source_e source);
   virtual void set_video_aspect_ratio(double aspect_ratio, bool is_factor, option_source_e source);
   virtual void set_video_pixel_cropping(int left, int top, int right, int bottom, option_source_e source);
