@@ -26,6 +26,7 @@ public:
     OftenUsedSelections,
     Languages,
     Merge,
+    MergeLayout,
     PredefinedValues,
     DefaultValues,
     DeriveTrackLanguage,
@@ -128,6 +129,7 @@ protected:
   void setupHeaderEditorDroppedFilesPolicy();
   void setupJobsRunPrograms();
   void setupFontAndScaling();
+  void setupPalette();
   void setupFileColorsControls();
   void setupFileColors(QVector<QColor> const &colors);
 
