@@ -77,6 +77,7 @@ char const * const s_valMergeAttachmentsAlwaysSkipForExistingName = "mergeAttach
 char const * const s_valMergeDragAndDropDirectoriesPolicy         = "mergeDragAndDropDirectoriesPolicy";
 char const * const s_valMergeDragAndDropFilesPolicy               = "mergeDragAndDropFilesPolicy";
 char const * const s_valMergeEnableDialogNormGainRemoval          = "mergeEnableDialogNormGainRemoval";
+char const * const s_valMergeEnsureAtLeastOneTrackEnabled         = "mergeEnsureAtLeastOneTrackEnabled";
 char const * const s_valMergeFileColors                           = "mergeFileColors";
 char const * const s_valMergeLastAddingAppendingDecision          = "mergeLastAddingAppendingDecision";
 char const * const s_valMergeLastDragAndDropFilesDecision         = "mergeLastDragAndDropFilesDecision";
@@ -135,6 +136,7 @@ char const * const s_valUiDisableToolTips                         = "uiDisableTo
 char const * const s_valUiFontFamily                              = "uiFontFamily";
 char const * const s_valUiFontPointSize                           = "uiFontPointSize";
 char const * const s_valUiLocale                                  = "uiLocale";
+char const * const s_valUiPalette                                 = "uiPalette";
 char const * const s_valUiStayOnTop                               = "uiStayOnTop";
 char const * const s_valUniqueOutputFileNames                     = "uniqueOutputFileNames";
 char const * const s_valUseDefaultJobDescription                  = "useDefaultJobDescription";
