@@ -32,7 +32,7 @@ generic_video_packetizer_c::generic_video_packetizer_c(generic_reader_c *p_reade
                                                        int64_t default_duration,
                                                        int width,
                                                        int height)
-  : generic_packetizer_c{p_reader, p_ti}
+  : generic_packetizer_c{p_reader, p_ti, track_video}
   , m_width{width}
   , m_height{height}
   , m_frames_output{}
@@ -41,8 +41,6 @@ generic_video_packetizer_c::generic_video_packetizer_c(generic_reader_c *p_reade
   , m_duration_shift{}
   , m_bframe_bref{-1}
 {
-  set_track_type(track_video);
-
   set_codec_id(codec_id);
   set_codec_private(m_ti.m_private_data);
 }
@@ -52,8 +50,7 @@ generic_video_packetizer_c::set_headers() {
   if (0 < m_default_duration)
     set_track_default_duration(m_default_duration);
 
-  set_video_pixel_width(m_width);
-  set_video_pixel_height(m_height);
+  set_video_pixel_dimensions(m_width, m_height);
 
   generic_packetizer_c::set_headers();
 
